@@ -1,7 +1,7 @@
-from protowhat.failure import _debug
-from protowhat.checks.check_simple import allow_errors
-from protowhat.checks.check_bash_history import has_command
-from protowhat.checks.check_files import check_file, has_dir
+from tcs_protowhat.failure import _debug
+from tcs_protowhat.checks.check_simple import allow_errors
+from tcs_protowhat.checks.check_bash_history import has_command
+from tcs_protowhat.checks.check_files import check_file, has_dir
 from tcs_pythonwhat.checks.check_funcs import check_part, check_part_index, check_node
 from tcs_pythonwhat.checks.has_funcs import has_equal_part
 from tcs_pythonwhat.checks.check_function import check_function
